@@ -1,22 +1,44 @@
+import logging
+
 import requests
 import argparse
 import json
 import datetime
 import sys
 import os
+from pathlib import Path
 
-#Replace with live server and live server key
-#DO NOT STORE KEY ON GITHUB
-#TEST settings for Sandbox
+from sas.system.legal import legal
+
+USAGE = '''This script should be run from one directory above the base sasview directory. This script also requires both
+ sasmodels and sasdata repositories to be in the same directory as the sasview repository.
+
+Usage: `python sasview/build_tools/release_automation.py [opts]`
+
+Options include:
+    -v/--sasview_version: The sasview version for the upcoming release in x.y.z(a|b)(0-9) format. **required**
+    -s/--sasmodels_version: The sasmodels version for the upcoming release in x.y.z(a|b)(0-9) format. **required**
+    -d/--sasdata_version: The sasdata version for the upcoming release in x.y.z(a|b)(0-9) format. **required**
+    -z/--zenodo: The Zenodo api key for modifying/creating Zenodo entries.
+    -u/--username: Your Github username for fetching the repositories.
+    -p/--password: Your Github password for fetching the repositories.
+    -l/--sasview_list: A comma-delimited list of sasview issue numbers closed for this release.
+    -m/--sasmodels_list: A comma-delimited list of sasmodels issue numbers closed for this release.
+    -n/--sasdata_list: A comma-delimited list of sasdata issue numbers closed for this release.
+'''
+
+# Replace with live server and live server key
+# DO NOT STORE KEY ON GITHUB
+# TEST settings for Sandbox
 zenodo_url = "https://zenodo.org"
 
-#Record metadata
-#Should import release notes from git repo, for now will need to cut and paste
+# Record metadata
+# Should import release notes from git repo, for now will need to cut and paste
 sasview_data = {
-    'metadata': {
-    'title': 'SasView version 5.0.6',
-    'description': '5.0.6 release',
-    'related_identifiers': [{'identifier': 'https://github.com/SasView/sasview/releases/tag/v5.0.6',
+'metadata': {
+    'title': f'SasView version 6.0.0',
+    'description': f'6.0.0 release',
+    'related_identifiers': [{'identifier': 'https://github.com/SasView/sasview/releases/tag/v6.0.0-beta-1',
                         'relation': 'isAlternateIdentifier', 'scheme': 'url'}],
     'contributors': [
         {'name': 'Anuchitanukul, Atijit', 'affiliation': 'STFC - Rutherford Appleton Laboratory', 'type':'Researcher'},
@@ -88,10 +110,58 @@ sasview_data = {
     }
 }
 
+CURRENT_PATH = Path('.').resolve()
+SASVIEW_PATH = CURRENT_PATH / 'sasview'
+SASDATA_PATH = CURRENT_PATH / 'sasdata'
+SASMODELS_PATH = CURRENT_PATH / 'sasmodels'
+for path in [SASMODELS_PATH, SASDATA_PATH, SASVIEW_PATH]:
+    if not path.exists():
+        missing_repo = path.parts[-1]
+        msg = f"""The {missing_repo} repository does not exist relative to the run path of release_automation.py.
+        Please ensure you are running this script from the directory all sub packages are in.
+        Usage:
+            `python ./sasview/release_automation.py [options]
+        """
+        logging.error(msg)
+CONTRIBUTORS_FILE = SASVIEW_PATH / 'build_tools' / 'contributors.csv'
+
+
 class SplitArgs(argparse.Action):
     def __call__(self, parser, namespace, values, option_string=None):
         setattr(namespace, self.dest, values.split(','))
 
+
+def generate_sasview_data() -> dict:
+    """Read in a known file and parse it for the information required to populate the list of participants used
+    in the zenodo record generation. The defined contributor types and difference between creators are defined in
+    https://help.zenodo.org/docs/deposit/describe-records/contributors/.
+
+    :return: A dictionary with a lists of creators and contributors."""
+    if CONTRIBUTORS_FILE.exists():
+        contributors = []
+        creators = []
+        with open(CONTRIBUTORS_FILE) as f:
+            # Rear in the lines and ignore the first line
+            lines = f.readlines()[1:]
+            for line in lines:
+                values = line.split('\t')
+                record = {'name': values[0], 'affiliation': values[1]}
+                if values[5]:
+                    # TODO: Should we grab the latest affiliation information using the ORCID ID?
+                    record['orcid'] = values[5]
+                if values[2]:
+                    creators.append(record)
+                elif values[3]:
+                    record['type'] = 'Producer'
+                    contributors.append(record)
+                elif values[4]:
+                    record['type'] = 'Other'
+                    contributors.append(record)
+        return {"creators": creators, "contributors": contributors}
+    else:
+        return {}
+
+
 def generate_zenodo(sasview_data, zenodo_api_key):
     """
     Generating zenodo record
@@ -136,28 +206,32 @@ def generate_zenodo(sasview_data, zenodo_api_key):
                                                             "and attach to Zenodo release record.\n- Publish Zenodo record")
     return newDOI
 
-def update_sasview_init(version, doi):
+
+version_template = \
+"""__version__ = "%s"
+__release_date__ = "%i"
+__build__ = "GIT_COMMIT"
+"""
+
+zenodo_template = '__DOI__ = "%s"'
+
+
+def update_sasview_metadata(version, doi):
+    """
+    Update version and zenodo DOI
     """
 
-    :return:
-    """
+    system_directory = "sasview/src/sas/system"
+    version_filename = os.path.join(system_directory, "version.py")
+    zenodo_filename = os.path.join(system_directory, "zenodo.py")
 
-    init_file = os.path.join('sasview','src', 'sas', 'sasview', '__init__.py')
-    output_lines = []
     year = datetime.datetime.now().year
-    with open(init_file, 'r') as f:
-        for line in f.readlines():
-            if line[:11] in '__version__':
-               output_lines.append('__version__ = \"'+version+'\"\n')
-            elif line[:7] in '__DOI__' :
-                output_lines.append('__DOI__ = \"Zenodo, ' + str(doi) + '\"\n')
-            elif line[:16] in '__release_date__':
-                output_lines.append('__release_date__ = \"' + str(year) + '\"\n')
-            else:
-                output_lines.append(line)
 
-    with open(init_file, 'w') as f:
-        f.writelines(output_lines)
+    with open(version_filename, 'w') as file:
+        file.write(version_template % (version, year))
+
+    with open(zenodo_filename, 'w') as file:
+        file.write(zenodo_template % doi)
 
 
 def update_sasmodels_init(version):
@@ -177,11 +251,27 @@ def update_sasmodels_init(version):
     with open(init_file, 'w') as f:
         f.writelines(output_lines)
 
-def update_file(license_file, license_line, line_to_update):
-    """
 
+def update_sasdata_init(version):
+    """Modify the sasdata __init__.py file in order to update the version
+
+    :param version:
     :return:
     """
+    init_file = CURRENT_PATH / 'sasdata' / 'sasdata' / '__init__.py'
+    output_lines = []
+    with open(init_file, 'r') as f:
+        for line in f.readlines():
+            if line[:11] == '__version__':
+                output_lines.append('__version__ = \"' + version + '\"\n')
+            else:
+                output_lines.append(line)
+    with open(init_file, 'w') as f:
+        f.writelines(output_lines)
+
+
+def update_file(license_file: Path, license_line: str, line_to_update: int):
+    """Update a specific line in a text file."""
     with open(license_file, 'r') as f:
         output_lines = f.readlines()
         output_lines[line_to_update] = license_line
@@ -204,14 +294,89 @@ def prepare_release_notes(issues_list, repository, username, password):
     """
     issue_titles = []
     for issue in issues_list:
-        #WARNING: One can try running with auth but there is limitted number of requests
+        # WARNING: One can try running with auth but there is limitted number of requests
         response = requests.get('https://api.github.com/repos/SasView/' + repository + '/issues/' + issue,
                                 auth=(username, password))
+        if response.status_code != 200:
+            return []
         title = response.json()['title']
-        issue_title = f"#{issue}, {title}"
-        issue_titles.append(issue_title)
+        issue_titles.append(f"#{issue}, {title}")
     return issue_titles
 
+
+def parse_args():
+    parser = argparse.ArgumentParser('Script to automate release process')
+    parser.add_argument('-v', '--sasview_version', required=True)
+    parser.add_argument('-s', '--sasmodels_version', required=True)
+    parser.add_argument('-d', '--sasdata_version', required=True)
+    parser.add_argument('-z', '--zenodo', default=False)
+    parser.add_argument('-u', '--username', default=False)
+    parser.add_argument('-p', '--password', default=False)
+    parser.add_argument('-l', '--sasview_list', default=False, action=SplitArgs)
+    parser.add_argument('-m', '--sasmodels_list', default=False, action=SplitArgs)
+    parser.add_argument('-n', '--sasdata_list', default=False, action=SplitArgs)
+    return parser.parse_args()
+
+
+def main(args=None):
+    if not args:
+        args = parse_args()
+
+    sasview_version = args.sasview_version
+    sasmodels_version = args.sasmodels_version
+    sasdata_version = args.sasdata_version
+    sasview_data['metadata']['title'] = 'SasView version ' + sasview_version
+    sasview_data['metadata']['description'] = sasview_version + ' release'
+    sasview_data['metadata']['related_identifiers'][0]['identifier'] = \
+        'https://github.com/SasView/sasview/releases/tag/v' + sasview_version
+    # Generate a list of contributors using a file, if that file exists, otherwise use the pre-defined list given here.
+    contributors = generate_sasview_data()
+    if contributors:
+        sasview_data.update(contributors)
+
+    # Generates zenodo doi if zenodo api key is provided
+    new_doi = ''
+    if args.zenodo:
+        zenodo_api_key = args.zenodo
+        new_doi = generate_zenodo(sasview_data, zenodo_api_key)
+
+    update_sasview_metadata(sasview_version, new_doi)
+    update_sasmodels_init(sasmodels_version)
+    update_sasdata_init(sasdata_version)
+
+    # Pull the license from a know location
+    license_line = legal.copyright
+    subpackages = [SASMODELS_PATH, SASDATA_PATH, SASVIEW_PATH]
+    for subpackage in subpackages:
+        license_file = subpackage / 'LICENSE.txt'
+        update_file(license_file, license_line, 0)
+    license_file = SASVIEW_PATH / 'installers' / 'license.txt'
+    update_file(license_file, license_line, -1)
+
+    sasview_issues_list = args.sasview_list
+    sasmodels_issues_list = args.sasmodels_list
+    sasdata_issues_list = args.sasdata_list
+
+    # Release notes template is generated if github credentials are provided
+    if args.username and args.password:
+        username = args.username
+        password = args.password
+
+        sasview_issues = prepare_release_notes(sasview_issues_list, 'sasview', username, password)
+        sasmodels_issues = prepare_release_notes(sasmodels_issues_list, 'sasmodels', username, password)
+        sasdata_issues = prepare_release_notes(sasdata_issues_list, 'sasmodels', username, password)
+
+        print('Copy text below to  /sasview/docs/sphinx-docs/source/user/RELEASE.rst and adapt accordingly')
+        for issue_title in sasview_issues:
+            print(f'Fixes sasview {issue_title}')
+
+        for issue_title in sasmodels_issues:
+            print(f'Fixes sasmodels {issue_title}')
+
+        for issue_title in sasdata_issues:
+            print(f'Fixes sasdata {issue_title}')
+
+
 if __name__ == "__main__":
     """
     Setups init and license files
@@ -219,56 +384,8 @@ if __name__ == "__main__":
     Templates release notes
     """
 
-    parser = argparse.ArgumentParser('Script to automate release process')
-    parser.add_argument('-v', '--sasview_version', required=True)
-    parser.add_argument('-s', '--sasmodels_version', required=True)
-    parser.add_argument('-z', '--zenodo', default=False)
-    parser.add_argument('-u', '--username', default=False)
-    parser.add_argument('-p', '--password', default=False)
-    parser.add_argument('-l', '--sasview_list', default=False, action=SplitArgs)
-    parser.add_argument('-m', '--sasmodels_list', default=False, action=SplitArgs)
-    args = parser.parse_args()
-
-    sasview_version = args.sasview_version
-    sasmodels_version = args.sasmodels_version
-    sasview_data['metadata']['title'] = 'SasView version '+ sasview_version
-    sasview_data['metadata']['description'] = sasview_version + ' release'
-    sasview_data['metadata']['related_identifiers'][0]['identifier'] = \
-        'https://github.com/SasView/sasview/releases/tag/v' + sasview_version
-
-    # Generates zenodo doi if zenodo api key is provided
-    new_doi = ''
-    if args.zenodo:
-        zenodo_api_key = args.zenodo
-        new_doi = generate_zenodo(sasview_data, zenodo_api_key)
-
-    update_sasview_init(sasview_version, new_doi)
-    update_sasmodels_init(sasmodels_version)
-
-    year = datetime.datetime.now().year
-    license_line = 'Copyright (c) 2009-' + str(year) + ', SasView Developers\n\n'
-    license_file = os.path.join('sasview', 'LICENSE.txt')
-    update_file(license_file, license_line, 0)
-    license_file = os.path.join('sasmodels', 'LICENSE.txt')
-    update_file(license_file, license_line, 0)
-    license_line = 'Copyright (c) 2009-' + str(year) + ' UTK, UMD, ESS, NIST, ORNL, ISIS, ILL, DLS, DUT, BAM\n'
-    license_file = os.path.join('sasview', 'installers', 'license.txt')
-    update_file(license_file, license_line, -1)
-
-    sasview_issues_list = args.sasview_list
-    sasmodels_issues_list = args.sasmodels_list
-
-    #Release notes template is generated if github credentials are provided
-    if args.username and args.password:
-        username = args.username
-        password = args.password
-
-        sasview_issues = prepare_release_notes(sasview_issues_list, 'sasview', username, password)
-        sasmodels_issues = prepare_release_notes(sasmodels_issues_list, 'sasmodels', username, password)
-
-        print('Copy text bellow to  /sasview/docs/sphinx-docs/source/user/RELEASE.rst and adapt accordingly')
-        for issue_title in sasview_issues:
-            print(f'Fixes sasview {issue_title}')
-
-        for issue_title in sasmodels_issues:
-            print(f'Fixes sasmodels {issue_title}')
+    args = parse_args()
+    if hasattr(args, 'help'):
+        print(USAGE)
+    else:
+        main(args)
