@@ -6,14 +6,14 @@ import time
 import logging
 import copy
 
-from PyQt5 import QtCore
-from PyQt5 import QtGui
-from PyQt5 import QtWidgets
+from PySide6 import QtCore
+from PySide6 import QtGui
+from PySide6 import QtWidgets
 
 from twisted.internet import threads
 
 # SASCALC
-from sas.sascalc.dataloader.loader import Loader
+from sasdata.dataloader.loader import Loader
 
 # QTGUI
 import sas.qtgui.Utilities.GuiUtils as GuiUtils
@@ -21,8 +21,9 @@ import sas.qtgui.Plotting.PlotHelper as PlotHelper
 
 from sas.qtgui.Plotting.PlotterData import Data1D
 from sas.qtgui.Plotting.PlotterData import Data2D
-from sas.qtgui.Plotting.Plotter import Plotter
-from sas.qtgui.Plotting.Plotter2D import Plotter2D
+from sas.qtgui.Plotting.PlotterData import DataRole
+from sas.qtgui.Plotting.Plotter import Plotter, PlotterWidget
+from sas.qtgui.Plotting.Plotter2D import Plotter2D, Plotter2DWidget
 from sas.qtgui.Plotting.MaskEditor import MaskEditor
 
 from sas.qtgui.MainWindow.DataManager import DataManager
@@ -30,10 +31,7 @@ from sas.qtgui.MainWindow.DroppableDataLoadWidget import DroppableDataLoadWidget
 from sas.qtgui.MainWindow.NameChanger import ChangeName
 
 import sas.qtgui.Perspectives as Perspectives
-
-DEFAULT_PERSPECTIVE = "Fitting"
-ANALYSIS_TYPES = ['Fitting (*.fitv)', 'Inversion (*.pr)', 'Invariant (*.inv)',
-                  'Corfunc (*.crf)', 'All Files (*.*)']
+from sas import config
 
 logger = logging.getLogger(__name__)
 
@@ -57,7 +55,6 @@ class DataExplorerWindow(DroppableDataLoadWidget):
 
         # Read in default locations
         self.default_save_location = None
-        self.default_load_location = GuiUtils.DEFAULT_OPEN_FOLDER
         self.default_project_location = None
 
         self.manager = manager if manager is not None else DataManager()
@@ -84,7 +81,9 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         self.cmdAppend_2.clicked.connect(self.appendPlot)
         self.cmdHelp.clicked.connect(self.displayHelp)
         self.cmdHelp_2.clicked.connect(self.displayHelp)
+        self.chkSwap.setVisible(False)
 
+        self.cmdFreeze.clicked.connect(self.freezeTheory)
         # Fill in the perspectives combo
         self.initPerspectives()
 
@@ -130,7 +129,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         self.theory_model.itemChanged.connect(self.onFileListChanged)
 
         # Don't show "empty" rows with data objects
-        self.data_proxy.setFilterRegExp(r"[^()]")
+        self.data_proxy.setFilterRegularExpression(QtCore.QRegularExpression(".+"))
 
         # Create a window to allow the display name to change
         self.nameChangeBox = ChangeName(self)
@@ -143,7 +142,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         self.theory_proxy.setSourceModel(self.theory_model)
 
         # Don't show "empty" rows with data objects
-        self.theory_proxy.setFilterRegExp(r"[^()]")
+        self.theory_proxy.setFilterRegularExpression(QtCore.QRegularExpression(".+"))
 
         # Theory model view
         self.freezeView.setModel(self.theory_proxy)
@@ -153,6 +152,23 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         # Current view on model
         self.current_view = self.treeView
 
+    @property
+    def default_load_location(self) -> str:
+        # Ensure the default load location is always read from the config
+        return config.DEFAULT_OPEN_FOLDER
+
+    @default_load_location.setter
+    def default_load_location(self, value: str):
+        # Ensure the config entry is updated
+        config.DEFAULT_OPEN_FOLDER = value
+
+    def createSendToMenu(self):
+        self.actionReplace = QtGui.QAction(self)
+        self.actionReplace.setObjectName(u"actionReplace")
+        self.actionReplace.setText(u"... replacing data in the current page")
+        self.send_menu = QtWidgets.QMenu(self)
+        self.send_menu.addAction(self.actionReplace)
+
     def closeEvent(self, event):
         """
         Overwrite the close event - no close!
@@ -186,8 +202,8 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         """
         Enables/disables "Assign Plot" elements
         """
-        self.cbgraph.setEnabled(len(PlotHelper.currentPlots()) > 0)
-        self.cmdAppend.setEnabled(len(PlotHelper.currentPlots()) > 0)
+        self.cbgraph.setEnabled(len(PlotHelper.currentPlotIds()) > 0)
+        self.cmdAppend.setEnabled(len(PlotHelper.currentPlotIds()) > 0)
 
     def initPerspectives(self):
         """
@@ -199,7 +215,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
             self.cbFitting.addItems(available_perspectives)
         self.cbFitting.currentIndexChanged.connect(self.updatePerspectiveCombo)
         # Set the index so we see the default (Fitting)
-        self.cbFitting.setCurrentIndex(self.cbFitting.findText(DEFAULT_PERSPECTIVE))
+        self.cbFitting.setCurrentIndex(self.cbFitting.findText(config.DEFAULT_PERSPECTIVE))
 
     def _perspective(self):
         """
@@ -211,10 +227,14 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         """
         Threaded file load
         """
+        self.default_load_location = os.path.dirname(url[0])
         load_thread = threads.deferToThread(self.readData, url)
         load_thread.addCallback(self.loadComplete)
         load_thread.addErrback(self.loadFailed)
 
+        # switch to data tab after reading from either file or folder
+        self.setCurrentIndex(0)
+
     def loadFile(self, event=None):
         """
         Called when the "Load" button pressed.
@@ -230,13 +250,11 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         Called when the "File/Load Folder" menu item chosen.
         Opens the Qt "Open Folder..." dialog
         """
-        kwargs = {
-            'parent'    : self,
-            'caption'   : 'Choose a directory',
-            'options'   : QtWidgets.QFileDialog.ShowDirsOnly | QtWidgets.QFileDialog.DontUseNativeDialog,
-            'directory' : self.default_load_location
-        }
-        folder = QtWidgets.QFileDialog.getExistingDirectory(**kwargs)
+        parent = self
+        caption = 'Choose a directory'
+        options = QtWidgets.QFileDialog.ShowDirsOnly
+        directory = self.default_load_location
+        folder = QtWidgets.QFileDialog.getExistingDirectory(parent, caption, directory, options)
 
         if folder is None:
             return
@@ -244,7 +262,6 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         folder = str(folder)
         if not os.path.isdir(folder):
             return
-        self.default_load_location = folder
         # get content of dir into a list
         path_str = [os.path.join(os.path.abspath(folder), filename)
                     for filename in os.listdir(folder)]
@@ -264,41 +281,40 @@ class DataExplorerWindow(DroppableDataLoadWidget):
             msgbox.setText(msg)
             msgbox.setWindowTitle("Project Load")
             # custom buttons
-            button_yes = QtWidgets.QPushButton("Yes")
-            msgbox.addButton(button_yes, QtWidgets.QMessageBox.YesRole)
-            button_no = QtWidgets.QPushButton("No")
-            msgbox.addButton(button_no, QtWidgets.QMessageBox.RejectRole)
-            retval = msgbox.exec_()
-            if retval == QtWidgets.QMessageBox.RejectRole:
+            msgbox.setStandardButtons(QtWidgets.QMessageBox.StandardButton.Yes |
+                                      QtWidgets.QMessageBox.StandardButton.No)
+            retval = msgbox.exec()
+            if retval == QtWidgets.QMessageBox.StandardButton.No:
                 # cancel fit
                 return
 
         kwargs = {
             'parent'    : self,
             'caption'   : 'Open Project',
-            'filter'    : 'Project Files (*.json);;Old Project Files (*.svs);;All files (*.*)',
-            'options'   : QtWidgets.QFileDialog.DontUseNativeDialog
+            'filter'    : 'Project Files (*.json);;Old Project Files (*.svs);;All files (*.*)'
         }
         filename = QtWidgets.QFileDialog.getOpenFileName(**kwargs)[0]
         if filename:
+            self.communicator.statusBarUpdateSignal.emit(f"Loading Project... {os.path.basename(filename)}")
             self.default_project_location = os.path.dirname(filename)
             # Delete all data and initialize all perspectives
             self.deleteAllItems()
-            self.cbFitting.disconnect()
+            self.cbFitting.blockSignals(True)
             self.parent.loadAllPerspectives()
+            self.cbFitting.blockSignals(False)
             self.initPerspectives()
             self.readProject(filename)
+            self.communicator.statusBarUpdateSignal.emit("Project loaded.")
 
     def loadAnalysis(self):
         """
         Called when the "Open Analysis" menu item chosen.
         """
-        file_filter = ';;'.join(ANALYSIS_TYPES)
+        file_filter = ';;'.join(config.ANALYSIS_TYPES + ['All Files (*.*)'])
         kwargs = {
             'parent'    : self,
             'caption'   : 'Open Analysis',
-            'filter'    : file_filter,
-            'options'   : QtWidgets.QFileDialog.DontUseNativeDialog
+            'filter'    : file_filter
         }
         filename = QtWidgets.QFileDialog.getOpenFileName(**kwargs)[0]
         if filename:
@@ -308,14 +324,11 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         """
         Called when the "Save Project" menu item chosen.
         """
-        kwargs = {
-            'parent'    : self,
-            'caption'   : 'Save Project',
-            'filter'    : 'Project (*.json)',
-            'options'   : QtWidgets.QFileDialog.DontUseNativeDialog,
-            'directory' : self.default_project_location
-        }
-        name_tuple = QtWidgets.QFileDialog.getSaveFileName(**kwargs)
+        parent = self
+        caption = 'Save Project'
+        filter = 'Project (*.json)'
+        directory = self.default_project_location
+        name_tuple = QtWidgets.QFileDialog.getSaveFileName(parent, caption, directory, filter, "")
         filename = name_tuple[0]
         if not filename:
             return
@@ -334,14 +347,12 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         default_name = "Analysis"+str(tab_id)+"."+str(extension)
 
         wildcard = "{0} files (*.{0})".format(extension)
-        kwargs = {
-            'caption'   : 'Save As',
-            'directory' : default_name,
-            'filter'    : wildcard,
-            'parent'    : None,
-        }
+        caption = 'Save As'
+        directory = default_name
+        filter = wildcard
+        parent = None
         # Query user for filename.
-        filename_tuple = QtWidgets.QFileDialog.getSaveFileName(**kwargs)
+        filename_tuple = QtWidgets.QFileDialog.getSaveFileName(parent, caption, directory, filter, "")
         filename = filename_tuple[0]
         return filename
 
@@ -401,8 +412,8 @@ class DataExplorerWindow(DroppableDataLoadWidget):
             if data is None: continue
             # Now, all plots under this item
             name = data.name
-            is_checked = item.checkState()
-            properties['checked'] = is_checked
+            is_checked_bool = item.checkState() == QtCore.Qt.Checked
+            properties['checked'] = is_checked_bool
             # save underlying theories
             other_datas = GuiUtils.plotsFromDisplayName(name, model)
             # skip the main plot
@@ -422,8 +433,8 @@ class DataExplorerWindow(DroppableDataLoadWidget):
                 if data.id != id: continue
                 # We found the dataset - save it.
                 name = data.name
-                is_checked = item.checkState()
-                properties['checked'] = is_checked
+                is_checked_bool = item.checkState() == QtCore.Qt.Checked
+                properties['checked'] = is_checked_bool
                 other_datas = GuiUtils.plotsFromDisplayName(name, model)
                 # skip the main plot
                 other_datas = list(other_datas.values())[1:]
@@ -509,7 +520,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
                     logging.error("Project load failed with " + str(ex))
                     return
         cs_keys = []
-        visible_perspective = DEFAULT_PERSPECTIVE
+        visible_perspective = config.DEFAULT_PERSPECTIVE
         for key, value in all_data.items():
             if key == 'is_batch':
                 self.chkBatch.setChecked(value == 'True')
@@ -530,7 +541,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
             self.updatePerspectiveWithProperties(key, value)
         # Set to fitting perspective and load in Batch and C&S Pages
         self.cbFitting.setCurrentIndex(
-            self.cbFitting.findText(DEFAULT_PERSPECTIVE))
+            self.cbFitting.findText(config.DEFAULT_PERSPECTIVE))
         # See if there are any batch pages defined and create them, if so
         self.updateWithBatchPages(all_data)
         # Get the constraint dict and apply it
@@ -584,7 +595,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
             items = self.updateModelFromData(data_dict)
 
         if 'fit_params' in value:
-            self.cbFitting.setCurrentIndex(self.cbFitting.findText(DEFAULT_PERSPECTIVE))
+            self.cbFitting.setCurrentIndex(self.cbFitting.findText(config.DEFAULT_PERSPECTIVE))
             params = value['fit_params']
             # Make the perspective read the rest of the read data
             if not isinstance(params, list):
@@ -636,8 +647,8 @@ class DataExplorerWindow(DroppableDataLoadWidget):
             # add the main index
             if not value: continue
             new_data = value[0]
-            from sas.sascalc.dataloader.data_info import Data1D as old_data1d
-            from sas.sascalc.dataloader.data_info import Data2D as old_data2d
+            from sasdata.dataloader.data_info import Data1D as old_data1d
+            from sasdata.dataloader.data_info import Data2D as old_data2d
             if isinstance(new_data, (old_data1d, old_data2d)):
                 new_data = self.manager.create_gui_data(value[0], new_data.name)
             if hasattr(value[0], 'id'):
@@ -648,7 +659,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
             properties = value[1]
             is_checked = properties['checked']
             new_item = GuiUtils.createModelItemWithPlot(new_data, new_data.name)
-            new_item.setCheckState(is_checked)
+            new_item.setCheckState(QtCore.Qt.Checked if is_checked else QtCore.Qt.Unchecked)
             items.append(new_item)
             model = self.theory_model
             if new_data.is_data:
@@ -672,8 +683,9 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         Delete selected rows from the model
         """
         # Assure this is indeed wanted
-        delete_msg = "This operation will delete the checked data sets and all the dependents." +\
-                     "\nDo you want to continue?"
+        delete_msg = "This operation will remove the selected data sets " +\
+                "and all the dependents from SasView." +\
+                "\nDo you want to continue?"
         reply = QtWidgets.QMessageBox.question(self,
                                                'Warning',
                                                delete_msg,
@@ -686,40 +698,34 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         # Figure out which rows are checked
         ind = -1
         # Use 'while' so the row count is forced at every iteration
-        deleted_items = []
-        deleted_names = []
         while ind < self.model.rowCount():
             ind += 1
             item = self.model.item(ind)
 
             if item and item.isCheckable() and item.checkState() == QtCore.Qt.Checked:
-                # Delete these rows from the model
-                deleted_names.append(str(self.model.item(ind).text()))
-                deleted_items.append(item)
-
                 # Delete corresponding open plots
                 self.closePlotsForItem(item)
                 # Close result panel if results represent the deleted data item
                 # Results panel only stores Data1D/Data2D object
                 #   => QStandardItems must still exist for direct comparison
-                self.closeResultPanelOnDelete(GuiUtils.dataFromItem(item))
+                data = GuiUtils.dataFromItem(item)
+                self.closeResultPanelOnDelete(data)
+
+                # Let others know we deleted data, before we delete it
+                self.communicator.dataDeletedSignal.emit([item])
+                # update stored_data
+                self.manager.update_stored_data([data.name])
 
                 self.model.removeRow(ind)
                 # Decrement index since we just deleted it
                 ind -= 1
 
-        # Let others know we deleted data
-        self.communicator.dataDeletedSignal.emit(deleted_items)
-
-        # update stored_data
-        self.manager.update_stored_data(deleted_names)
-
     def deleteTheory(self, event):
         """
         Delete selected rows from the theory model
         """
         # Assure this is indeed wanted
-        delete_msg = "This operation will delete the checked data sets and all the dependents." +\
+        delete_msg = "This operation remove the checked data sets and their dependents from the data explorer." +\
                      "\nDo you want to continue?"
         reply = QtWidgets.QMessageBox.question(self,
                                                'Warning',
@@ -732,46 +738,44 @@ class DataExplorerWindow(DroppableDataLoadWidget):
 
         # Figure out which rows are checked
         ind = -1
-
-        deleted_items = []
-        deleted_names = []
         while ind < self.theory_model.rowCount():
             ind += 1
             item = self.theory_model.item(ind)
 
             if item and item.isCheckable() and item.checkState() == QtCore.Qt.Checked:
                 # Delete these rows from the model
-                deleted_names.append(str(self.theory_model.item(ind).text()))
-                deleted_items.append(item)
                 self.closePlotsForItem(item)
+                # Let others know we deleted data
+                self.communicator.dataDeletedSignal.emit([item])
 
+                # update stored_data
+                self.manager.update_stored_data([item])
                 self.theory_model.removeRow(ind)
                 # Decrement index since we just deleted it
                 ind -= 1
 
-        # Let others know we deleted data
-        self.communicator.dataDeletedSignal.emit(deleted_items)
-
-        # update stored_data
-        self.manager.update_stored_data(deleted_names)
-
-    def sendData(self, event=None):
+    def selectedItems(self):
         """
-        Send selected item data to the current perspective and set the relevant notifiers
+        Returns the selected items from the current view
         """
         def isItemReady(index):
             item = self.model.item(index)
             return item.isCheckable() and item.checkState() == QtCore.Qt.Checked
-
         # Figure out which rows are checked
         selected_items = [self.model.item(index)
                           for index in range(self.model.rowCount())
                           if isItemReady(index)]
+        return selected_items
 
+    def onDataReplaced(self):
+        """
+        Called when data is to be replaced in the current fitting tab.
+        """
+        selected_items = self.selectedItems()
         if len(selected_items) < 1:
             return
         #Check that you have only one box item checked when swaping data
-        if len(selected_items) > 1 and (self.chkSwap.isChecked() or not self._perspective().allowBatch()):
+        if len(selected_items) > 1 and not self._perspective().allowBatch():
             if hasattr(self._perspective(), 'name'):
                 title = self._perspective().name
             else:
@@ -783,16 +787,32 @@ class DataExplorerWindow(DroppableDataLoadWidget):
             msgbox.setStandardButtons(QtWidgets.QMessageBox.Ok)
             _ = msgbox.exec_()
             return
-
-        # Notify the GuiManager about the send request
         try:
-            if self.chkSwap.isChecked():
-                self._perspective().swapData(selected_items[0])
-            else:
-                self._perspective().setData(data_item=selected_items, is_batch=self.chkBatch.isChecked())
+            self._perspective().swapData(selected_items[0])
         except Exception as ex:
             msg = "%s perspective returned the following message: \n%s\n" % (self._perspective().name, str(ex))
-            logging.error(msg)
+            logging.error(ex, exc_info=True)
+            msg = str(ex)
+            msgbox = QtWidgets.QMessageBox()
+            msgbox.setIcon(QtWidgets.QMessageBox.Critical)
+            msgbox.setText(msg)
+            msgbox.setStandardButtons(QtWidgets.QMessageBox.Ok)
+            _ = msgbox.exec_()
+
+    def sendData(self, event=None):
+        """
+        Send selected item data to the current perspective and set the relevant notifiers
+        """
+        selected_items = self.selectedItems()
+        if len(selected_items) < 1:
+            return
+ 
+        # Notify the GuiManager about the send request
+        try:
+            self._perspective().setData(data_item=selected_items, is_batch=self.chkBatch.isChecked())
+        except Exception as ex:
+            msg = "%s perspective returned the following message: \n%s\n" % (self._perspective().name, str(ex))
+            logging.error(ex, exc_info=True)
             msg = str(ex)
             msgbox = QtWidgets.QMessageBox()
             msgbox.setIcon(QtWidgets.QMessageBox.Critical)
@@ -966,7 +986,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         deleted graphs
         """
         graph2, delete = graphs
-        graph_list = PlotHelper.currentPlots()
+        graph_list = PlotHelper.currentPlotIds()
         self.updateGraphCombo(graph_list)
 
         if not self.active_plots:
@@ -992,16 +1012,36 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         if ind > 0:
             graph.setCurrentIndex(ind)
 
+    def sendToMenu(self, hasSubmenu=False):
+        # add menu to cmdSendTO
+        if hasSubmenu:
+            self.createSendToMenu()
+            self.cmdSendTo.setMenu(self.send_menu)
+            self.cmdSendTo.setPopupMode(QtWidgets.QToolButton.MenuButtonPopup)
+        else:
+            self.cmdSendTo.setMenu(None)
+            self.cmdSendTo.setPopupMode(QtWidgets.QToolButton.InstantPopup)
+
     def updatePerspectiveCombo(self, index):
         """
         Notify the gui manager about the new perspective chosen.
         """
+
+        # Check that a valid index has been chosen, can happen in some cases such a loading projects
+        if index < 0:
+            return
+
+        # Notify via communicator
         self.communicator.perspectiveChangedSignal.emit(self.cbFitting.itemText(index))
-        self.chkBatch.setEnabled(self.parent.perspective().allowBatch())
-        # Deactivate and uncheck the swap data option if the current perspective does not allow it
-        self.chkSwap.setEnabled(self.parent.perspective().allowSwap())
-        if not self.parent.perspective().allowSwap():
-            self.chkSwap.setCheckState(False)
+
+        # Set checkboxes
+        current_perspective = self.parent.perspective()
+
+        allow_batch = False if current_perspective is None else current_perspective.allowBatch()
+        allow_swap = False if current_perspective is None else current_perspective.allowSwap()
+
+        self.chkBatch.setEnabled(allow_batch)
+        self.sendToMenu(hasSubmenu=allow_swap)
 
     def itemFromDisplayName(self, name):
         """
@@ -1036,7 +1076,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
                     or name in plot.name
                     or name == plot.filename):
                 # Residuals get their own plot
-                if plot.plot_role == Data1D.ROLE_RESIDUAL:
+                if plot.plot_role in [DataRole.ROLE_RESIDUAL, DataRole.ROLE_STAND_ALONE]:
                     plot.yscale = 'linear'
                     self.plotData([(item, plot)])
                 else:
@@ -1083,13 +1123,19 @@ class DataExplorerWindow(DroppableDataLoadWidget):
 
             plot_name = plot_to_show.name
             role = plot_to_show.plot_role
+            stand_alone_types = [DataRole.ROLE_RESIDUAL, DataRole.ROLE_STAND_ALONE, DataRole.ROLE_POLYDISPERSITY]
 
-            if (role == Data1D.ROLE_RESIDUAL and shown) or role == Data1D.ROLE_DELETABLE:
-                # Nothing to do if separate plot already shown or to be deleted
+            if (role in stand_alone_types and shown) or role == DataRole.ROLE_DELETABLE:
+                # Nothing to do if stand-alone plot already shown or plot to be deleted
                 continue
-            elif role == Data1D.ROLE_RESIDUAL:
-                # Residual plots should always be separate
-                plot_to_show.yscale='linear'
+            elif role == DataRole.ROLE_RESIDUAL and config.DISABLE_RESIDUAL_PLOT:
+                # Nothing to do if residuals are not plotted
+                continue
+            elif role == DataRole.ROLE_POLYDISPERSITY and config.DISABLE_POLYDISPERSITY_PLOT:
+                # Nothing to do if polydispersity plot is not plotted
+                continue
+            elif role in stand_alone_types:
+                # Stand-alone plots should always be separate
                 self.plotData([(plot_item, plot_to_show)])
             elif append:
                 # Assume all other plots sent together should be on the same chart if a previous plot exists
@@ -1121,7 +1167,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         if not hasattr(plot, 'name'):
             return False
         ids_vals = [val.data[0].name for val in self.active_plots.values()]
-                    #if val.data[0].plot_role != Data1D.ROLE_DATA]
+                    #if val.data[0].plot_role != DataRole.ROLE_DATA]
 
         return plot.name in ids_vals
 
@@ -1129,7 +1175,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         """
         Create a new 2D plot and add it to the workspace
         """
-        plot2D = Plotter2D(self)
+        plot2D = Plotter2DWidget(parent=self, manager=self)
         plot2D.item = item
         plot2D.plot(plot_set)
         self.addPlot(plot2D)
@@ -1157,8 +1203,12 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         for item, plot_set in plots:
             if isinstance(plot_set, Data1D):
                 if 'new_plot' not in locals():
-                    new_plot = Plotter(self)
+                    new_plot = PlotterWidget(manager=self, parent=self)
                     new_plot.item = item
+                # Ensure new plots use the default transform, not the transform of any previous plots the data were in
+                # TODO: The transform should be part of the PLOT, NOT the data
+                plot_set.xtransform = None
+                plot_set.ytransform = None
                 new_plot.plot(plot_set, transform=transform)
                 # active_plots may contain multiple charts
                 self.active_plots[plot_set.name] = new_plot
@@ -1228,7 +1278,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         # old plot data
         plot_id = str(graph.currentText())
         try:
-            assert plot_id in PlotHelper.currentPlots(), "No such plot: %s" % (plot_id)
+            assert plot_id in PlotHelper.currentPlotIds(), "No such plot: %s" % (plot_id)
         except:
             return
 
@@ -1242,7 +1292,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
     @staticmethod
     def appendOrUpdatePlot(self, data, plot):
         name = data.name
-        if isinstance(plot, Plotter2D) or name in plot.plot_dict.keys():
+        if isinstance(plot, Plotter2DWidget) or name in plot.plot_dict.keys():
             plot.replacePlot(name, data)
         else:
             plot.plot(data)
@@ -1264,13 +1314,13 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         data_id = data.name
         if data_id in ids_keys:
             # We have data, let's replace data that needs replacing
-            if data.plot_role != Data1D.ROLE_DATA:
+            if data.plot_role != DataRole.ROLE_DATA:
                 self.active_plots[data_id].replacePlot(data_id, data)
                 # restore minimized window, if applicable
                 self.active_plots[data_id].showNormal()
             return True
         #elif data_id in ids_vals:
-        #    if data.plot_role != Data1D.ROLE_DATA:
+        #    if data.plot_role != DataRole.ROLE_DATA:
         #        list(self.active_plots.values())[ids_vals.index(data_id)].replacePlot(data_id, data)
         #        self.active_plots[data_id].showNormal()
         #    return True
@@ -1284,22 +1334,18 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         wlist = self.getWlist()
         # Location is automatically saved - no need to keep track of the last dir
         # But only with Qt built-in dialog (non-platform native)
-        kwargs = {
-            'parent'    : self,
-            'caption'   : 'Choose files',
-            'filter'    : wlist,
-            'options'   : QtWidgets.QFileDialog.DontUseNativeDialog |
-                          QtWidgets.QFileDialog.DontUseCustomDirectoryIcons,
-            'directory' : self.default_load_location
-        }
-        paths = QtWidgets.QFileDialog.getOpenFileNames(**kwargs)[0]
+        parent = self
+        caption = 'Choose files'
+        directory = self.default_load_location
+        filter = wlist
+        paths = QtWidgets.QFileDialog.getOpenFileNames(parent, caption, directory, filter)[0]
+
         if not paths:
             return
 
         if not isinstance(paths, list):
             paths = [paths]
 
-        self.default_load_location = os.path.dirname(paths[0])
         return paths
 
     def readData(self, path):
@@ -1315,12 +1361,16 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         data_error = False
         error_message = ""
         number_of_files = len(path)
-        self.communicator.progressBarUpdateSignal.emit(0.0)
+        self.communicator.progressBarUpdateSignal.emit(0)
 
         for index, p_file in enumerate(path):
             basename = os.path.basename(p_file)
             _, extension = os.path.splitext(basename)
-            if extension.lower() in GuiUtils.EXTENSIONS:
+            extension_list = config.PLUGIN_STATE_EXTENSIONS.copy()
+            if config.APPLICATION_STATE_EXTENSION is not None:
+                extension_list.append(config.APPLICATION_STATE_EXTENSION)
+
+            if extension.lower() in extension_list:
                 any_error = True
                 log_msg = "Data Loader cannot "
                 log_msg += "load: %s\n" % str(p_file)
@@ -1339,7 +1389,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
                 output_objects = self.loader.load(p_file)
 
                 for item in output_objects:
-                    # cast sascalc.dataloader.data_info.Data1D into
+                    # cast sasdata.dataloader.data_info.Data1D into
                     # sasgui.guiframe.dataFitting.Data1D
                     # TODO : Fix it
                     new_data = self.manager.create_gui_data(item, p_file)
@@ -1512,6 +1562,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         self.actionEditMask.triggered.connect(self.showEditDataMask)
         self.actionDelete.triggered.connect(self.deleteSelectedItem)
         self.actionFreezeResults.triggered.connect(self.freezeSelectedItems)
+        self.actionReplace.triggered.connect(self.onDataReplaced)
 
     def onCustomContextMenu(self, position):
         """
@@ -1783,8 +1834,8 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         Delete the current item
         """
         # Assure this is indeed wanted
-        delete_msg = "This operation will delete the selected data sets " +\
-                     "and all the dependents." +\
+        delete_msg = "This operation will remove the selected data sets " +\
+                     "and all the dependents from SasView." +\
                      "\nDo you want to continue?"
         reply = QtWidgets.QMessageBox.question(self,
                                                'Warning',
@@ -1843,7 +1894,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         Close all currently displayed plots
         """
 
-        for plot_id in PlotHelper.currentPlots():
+        for plot_id in PlotHelper.currentPlotIds():
             try:
                 plotter = PlotHelper.plotById(plot_id)
                 plotter.close()
@@ -1856,7 +1907,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         """
         Minimize all currently displayed plots
         """
-        for plot_id in PlotHelper.currentPlots():
+        for plot_id in PlotHelper.currentPlotIds():
             plotter = PlotHelper.plotById(plot_id)
             plotter.showMinimized()
 
@@ -1868,7 +1919,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
 
         # {} -> 'Graph1' : HashableStandardItem()
         current_plot_items = {}
-        for plot_name in PlotHelper.currentPlots():
+        for plot_name in PlotHelper.currentPlotIds():
             current_plot_items[plot_name] = PlotHelper.plotById(plot_name).item
 
         # item and its hashable children
@@ -1910,10 +1961,12 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         Update the perspective combo index based on passed string
         """
         assert new_perspective_name in Perspectives.PERSPECTIVES.keys()
+
         self.cbFitting.blockSignals(True)
-        self.cbFitting.setCurrentIndex(self.cbFitting.findText(new_perspective_name))
+        index = self.cbFitting.findText(new_perspective_name)
+        self.cbFitting.setCurrentIndex(index)
         self.cbFitting.blockSignals(False)
-        pass
+
 
     def loadComplete(self, output):
         """
