@@ -1,13 +1,12 @@
 import numpy as np
 
-from sas.qtgui.Plotting.PlotterData import Data1D
-from sas.qtgui.Plotting.PlotterData import Data2D
+from sas.qtgui.Plotting.PlotterData import Data1D, Data2D, DataRole
 
-from sas.sascalc.dataloader.data_info import Detector
-from sas.sascalc.dataloader.data_info import Source
+from sasdata.dataloader.data_info import Detector
+from sasdata.dataloader.data_info import Source
 
 
-class FittingLogic(object):
+class FittingLogic:
     """
     All the data-related logic. This class deals exclusively with Data1D/2D
     No QStandardModelIndex here.
@@ -155,7 +154,7 @@ class FittingLogic(object):
         new_plot.yaxis(_yaxis, _yunit)
 
         if component is not None:
-            new_plot.plot_role = Data1D.ROLE_DELETABLE #deletable
+            new_plot.plot_role = DataRole.ROLE_DELETABLE #deletable
 
         return new_plot
 
