@@ -9,9 +9,11 @@ their distribution as a function of D_max.
 # global
 import logging
 import numpy as np
-from PyQt5 import QtCore
-from PyQt5 import QtGui
-from PyQt5 import QtWidgets
+from PySide6 import QtCore
+from PySide6 import QtGui
+from PySide6 import QtWidgets
+from PySide6.QtCore import QSize
+from PySide6.QtGui import QIcon
 
 # sas-global
 from sas.qtgui.Plotting.PlotterData import Data1D
@@ -43,6 +45,10 @@ class DmaxWindow(QtWidgets.QDialog, Ui_DmaxExplorer):
 
         self.setWindowTitle("Dmax Explorer")
 
+        icon = QIcon()
+        icon.addFile(u":/res/ball.ico", QSize(), QIcon.Normal, QIcon.Off)
+        self.setWindowIcon(icon)
+
         self.pr_state = pr_state
         self.nfunc = nfunc
         self.communicator = GuiUtils.Communicate()
