@@ -1,15 +1,16 @@
-from PyQt5 import QtGui
-from PyQt5 import QtWidgets
+from PySide6 import QtGui
+from PySide6 import QtWidgets
 
 import functools
 import copy
-import sys
+import math
 import matplotlib as mpl
 import numpy as np
+import textwrap
 from matplotlib.font_manager import FontProperties
 from packaging import version
 
-from sas.qtgui.Plotting.PlotterData import Data1D
+from sas.qtgui.Plotting.PlotterData import Data1D, DataRole
 from sas.qtgui.Plotting.PlotterBase import PlotterBase
 from sas.qtgui.Plotting.AddText import AddText
 from sas.qtgui.Plotting.Binder import BindArtist
@@ -18,40 +19,20 @@ from sas.qtgui.Plotting.LinearFit import LinearFit
 from sas.qtgui.Plotting.QRangeSlider import QRangeSlider
 from sas.qtgui.Plotting.PlotProperties import PlotProperties
 from sas.qtgui.Plotting.ScaleProperties import ScaleProperties
+from sas.qtgui.Plotting.PlotLabelProperties import PlotLabelProperties
+from sas.qtgui.Plotting.PlotLabelProperties import PlotLabelPropertyHolder
 
 import sas.qtgui.Utilities.GuiUtils as GuiUtils
 import sas.qtgui.Plotting.PlotUtilities as PlotUtilities
 
-def _legendResize(width, parent):
-    """
-    resize factor for the legend, based on total canvas width
-    """
-    # The factor 4.0 was chosen to look similar in size/ratio to what we had in 4.x
-    if not hasattr(parent.parent, "manager"):
-        return None
-    if parent is None or parent.parent is None or parent.parent.manager is None \
-        or parent.parent.manager.parent is None or parent.parent.manager.parent._parent is None:
-        return None
-
-    screen_width = parent.parent.manager.parent._parent.screen_width
-    screen_height = parent.parent.manager.parent._parent.screen_height
-    screen_factor = screen_width * screen_height
-
-    if sys.platform == 'win32':
-        factor = 4
-        denomintor = 100
-        scale_factor = width/denomintor + factor
-    else:
-        #Function inferred based on tests for several resolutions
-        scale_factor = (3e-6*screen_factor + 1)*width/640
-    return scale_factor
+from sas import config
 
 class PlotterWidget(PlotterBase):
     """
     1D Plot widget for use with a QDialog
     """
     def __init__(self, parent=None, manager=None, quickplot=False):
-        super(PlotterWidget, self).__init__(parent, manager=manager, quickplot=quickplot)
+        super().__init__(parent, manager=manager, quickplot=quickplot)
 
         self.parent = parent
 
@@ -88,7 +69,8 @@ class PlotterWidget(PlotterBase):
 
         self.legendVisible = True
 
-        parent.geometry()
+        if parent is not None:
+            parent.geometry()
 
     @property
     def data(self):
@@ -188,6 +170,9 @@ class PlotterWidget(PlotterBase):
         if color is None:
             color = data.custom_color
 
+        # grid on/off, stored on self
+        ax.grid(self.grid_on)
+
         color = PlotUtilities.getValidColor(color)
         data.custom_color = color
 
@@ -245,6 +230,12 @@ class PlotterWidget(PlotterBase):
         if data.show_yzero:
             ax.axhline(color='black', linewidth=1)
 
+        # Display +/- 3 sigma and +/- 1 sigma lines for residual plots
+        if data.plot_role == DataRole.ROLE_RESIDUAL:
+            ax.axhline(y=3, color='red', linestyle='-')
+            ax.axhline(y=-3, color='red', linestyle='-')
+            ax.axhline(y=1, color='gray', linestyle='--')
+            ax.axhline(y=-1, color='gray', linestyle='--')
         # Update the list of data sets (plots) in chart
         self.plot_dict[data.name] = data
 
@@ -252,14 +243,28 @@ class PlotterWidget(PlotterBase):
 
         # Now add the legend with some customizations.
         if self.showLegend:
-            width=_legendResize(self.canvas.size().width(), self.parent)
-            if width is not None:
-                self.legend = ax.legend(loc='upper right', shadow=True, prop={'size':width})
+            max_legend_width = config.FITTING_PLOT_LEGEND_MAX_LINE_LENGTH
+            handles, labels = ax.get_legend_handles_labels()
+            newhandles = []
+            newlabels = []
+            for h,l in zip(handles,labels):
+                    if config.FITTING_PLOT_LEGEND_TRUNCATE:
+                        if len(l)> config.FITTING_PLOT_LEGEND_MAX_LINE_LENGTH:
+                            half_legend_width = math.floor(max_legend_width/2)
+                            newlabels.append(f'{l[0:half_legend_width-3]} .. {l[-half_legend_width+3:]}')
+                        else:
+                            newlabels.append(l)
+                    else:
+                        newlabels.append(textwrap.fill(l,max_legend_width))
+                    newhandles.append(h)
+
+            if config.FITTING_PLOT_FULL_WIDTH_LEGENDS:
+                self.legend = ax.legend(newhandles,newlabels,loc='best', mode='expand')
             else:
-                self.legend = ax.legend(loc='upper right', shadow=True)
-            if self.legend:
-                self.legend.set_picker(True)
+                self.legend = ax.legend(newhandles,newlabels,loc='best', shadow=True)
+            self.legend.set_picker(True)
             self.legend.set_visible(self.legendVisible)
+            
         # Current labels for axes
         if self.yLabel and not is_fit:
             ax.set_ylabel(self.yLabel)
@@ -274,11 +279,29 @@ class PlotterWidget(PlotterBase):
             default_y_range = self.setRange.defaultYRange
             x_range = self.setRange.xrange()
             y_range = self.setRange.yrange()
+
+        elif isinstance(data, Data1D):
+            # Get default ranges from data
+
+            if self.has_nonempty_plots():
+                x_range, y_range = self._plot_bounds()
+
+            else:
+
+                x_range = self.ax.get_xlim()
+                y_range = self.ax.get_ylim()
+
+            default_x_range, default_y_range = x_range, y_range
+
+            modified = False
         else:
             # Use default ranges given by matplotlib
-            x_range = default_x_range = self.ax.get_xlim()
-            y_range = default_y_range = self.ax.get_ylim()
+            default_x_range = self.ax.get_xlim()
+            default_y_range = self.ax.get_ylim()
+            x_range = default_x_range
+            y_range = default_y_range
             modified = False
+
         self.setRange = SetGraphRange(parent=self, x_range=x_range, y_range=y_range)
         self.setRange.rangeModified = modified
         self.setRange.defaultXRange = default_x_range
@@ -300,16 +323,57 @@ class PlotterWidget(PlotterBase):
         # refresh canvas
         self.canvas.draw_idle()
 
-    def onResize(self, event):
+    def has_nonempty_plots(self) -> bool:
+
+        for key in self.plot_dict:
+            if len(self.plot_dict[key].x) > 0:
+                return True
+
+        return False
+
+    def _plot_bounds(self, offset=0.05) -> tuple[tuple[float, float], tuple[float, float]]:
+        """ Get the appropriate bounds for the plots
+
+        :param offset: add a small fraction of the absolute value of each end to each end
+        :returns:
         """
-        Resize the legend window/font on canvas resize
-        """
-        if not self.showLegend or not self.legendVisible:
-            return
-        width = _legendResize(event.width, self.parent)
-        # resize the legend to follow the canvas width.
-        if width is not None:
-            self.legend.prop.set_size(width)
+
+
+        x_min, x_max = np.inf, -np.inf
+        y_min, y_max = np.inf, -np.inf
+
+        for key in self.plot_dict:
+
+            plot_data = self.plot_dict[key]
+
+            if len(plot_data.x) > 0:
+                x_min = min(np.min(plot_data.x), x_min)
+                x_max = max(np.max(plot_data.x), x_max)
+
+            if len(plot_data.y) > 0:
+
+                dy = plot_data.view.dy
+                if dy is None:
+                    y_min = min(np.min(plot_data.y), y_min)
+                    y_max = max(np.max(plot_data.y), y_max)
+                else:
+                    try:
+                        y_min = min(np.min(np.array(plot_data.y) - np.array(dy)), y_min)
+                        y_max = max(np.max(np.array(plot_data.y) + np.array(dy)), y_max)
+                    except ValueError:
+                        # Ignore error term if it doesn't match y scale and causes an error
+                        
+                        y_min = min(np.min(plot_data.y), y_min)
+                        y_max = max(np.max(plot_data.y), y_max)
+
+        x_pad = offset*(x_max - x_min)
+        y_pad = offset*(y_max - y_min)
+
+        return ((float(x_min - x_pad),
+                 float(x_max + x_pad)),
+                (float(y_min - y_pad),
+                 float(y_max + y_pad)))
+
 
     def createContextMenu(self):
         """
@@ -325,9 +389,13 @@ class PlotterWidget(PlotterBase):
         self.actionAddText = self.contextMenu.addAction("Add Text")
         self.actionRemoveText = self.contextMenu.addAction("Remove Text")
         self.contextMenu.addSeparator()
+        self.actionToggleGrid = self.contextMenu.addAction("Toggle Grid On/Off")
         if self.show_legend:
             self.actionToggleLegend = self.contextMenu.addAction("Toggle Legend")
             self.contextMenu.addSeparator()
+        # Additional actions
+        self.actionCustomizeLabel = self.contextMenu.addAction("Customize Labels")
+        self.contextMenu.addSeparator()
         self.actionChangeScale = self.contextMenu.addAction("Change Scale")
         self.contextMenu.addSeparator()
         self.actionSetGraphRange = self.contextMenu.addAction("Set Graph Range")
@@ -345,11 +413,13 @@ class PlotterWidget(PlotterBase):
         self.actionRemoveText.triggered.connect(self.onRemoveText)
         self.actionChangeScale.triggered.connect(self.onScaleChange)
         self.actionSetGraphRange.triggered.connect(self.onSetGraphRange)
+        self.actionToggleGrid.triggered.connect(self.onGridToggle)
         self.actionResetGraphRange.triggered.connect(self.onResetGraphRange)
         self.actionWindowTitle.triggered.connect(self.onWindowsTitle)
         self.actionToggleMenu.triggered.connect(self.onToggleMenu)
         if self.show_legend:
             self.actionToggleLegend.triggered.connect(self.onToggleLegend)
+        self.actionCustomizeLabel.triggered.connect(self.onCusotmizeLabel)
 
     def addPlotsToContextMenu(self):
         """
@@ -393,7 +463,7 @@ class PlotterWidget(PlotterBase):
 
             if plot.is_data:
                 self.actionHideError = plot_menu.addAction("Hide Error Bar")
-                if plot.dy is not None and plot.dy != []:
+                if plot.dy is not None and len(plot.dy)>0:
                     if plot.hide_error:
                         self.actionHideError.setText('Show Error Bar')
                 else:
@@ -461,10 +531,9 @@ class PlotterWidget(PlotterBase):
         # MPL style names
         styles = ['normal', 'italic', 'oblique']
         # QFont::Style maps directly onto the above
-        try:
-            mpl_font.set_style(styles[extra_font.style()])
-        except:
-            pass
+        # Get an index of the font style which we can then lookup in the styles list.
+        font_index = extra_font.style().value
+        mpl_font.set_style(styles[font_index])
 
         if len(extra_text) > 0:
             new_text = self.ax.text(pos_x,
@@ -799,10 +868,63 @@ class PlotterWidget(PlotterBase):
         self.legend.set_visible(self.legendVisible)
         self.canvas.draw_idle()
 
+    def onCusotmizeLabel(self):
+        """
+        Show label customization widget
+        """
+        xl = self.ax.xaxis.label
+        yl = self.ax.yaxis.label
+        font_x = PlotLabelPropertyHolder(
+            size=xl.get_fontsize(),
+            font=xl.get_family()[0],
+            color=xl.get_color(),
+            weight=xl.get_weight(),
+            text=xl.get_text())
+
+        font_y = PlotLabelPropertyHolder(
+            size=yl.get_fontsize(),
+            font=yl.get_family()[0],
+            color=yl.get_color(),
+            weight=yl.get_weight(),
+            text=yl.get_text())
+
+        labelWidget = PlotLabelProperties(self, x_props=font_x, y_props=font_y)
+
+        if labelWidget.exec_() != QtWidgets.QDialog.Accepted:
+            return
+
+        fx = labelWidget.fx()
+        fy = labelWidget.fy()
+        label_x = labelWidget.text_x()
+        label_y = labelWidget.text_y()
+        apply_x = labelWidget.apply_to_ticks_x()
+        apply_y = labelWidget.apply_to_ticks_y()
+
+        self.ax.set_xlabel(label_x, fontdict=fx)
+        self.ax.set_ylabel(label_y, fontdict=fy)
+        if apply_x:
+            # self.ax.tick_params(axis='x', labelsize=fx.size, labelcolor=fx.color)
+            from matplotlib.pyplot import gca
+            a = gca()
+            a.set_xticklabels(a.get_xticks(), fx)
+        if apply_y:
+            # self.ay.tick_params(axis='y', labelsize=fy.size, labelcolor=fy.color)
+            from matplotlib.pyplot import gca
+            a = gca()
+            a.set_yticklabels(a.get_yticks(), fy)
+        self.canvas.draw_idle()
+
     def onMplMouseDown(self, event):
         """
         Left button down and ready to drag
         """
+        # Before checking if this mouse click is a left click, we need to update the position of the mouse regardless as
+        # this may be needed by other events (e.g. adding text)
+        try:
+            self.x_click = float(event.xdata)  # / size_x
+            self.y_click = float(event.ydata)  # / size_y
+        except:
+            self.position = None
         # Check that the LEFT button was pressed
         if event.button != 1:
             return
@@ -814,11 +936,6 @@ class PlotterWidget(PlotterBase):
                 return
         if event.inaxes is None:
             return
-        try:
-            self.x_click = float(event.xdata)  # / size_x
-            self.y_click = float(event.ydata)  # / size_y
-        except:
-            self.position = None
 
         x_str = GuiUtils.formatNumber(self.x_click)
         y_str = GuiUtils.formatNumber(self.y_click)
@@ -973,8 +1090,7 @@ class PlotterWidget(PlotterBase):
 class Plotter(QtWidgets.QDialog, PlotterWidget):
     def __init__(self, parent=None, quickplot=False):
 
-        QtWidgets.QDialog.__init__(self)
-        PlotterWidget.__init__(self, parent=self, manager=parent, quickplot=quickplot)
+        PlotterWidget.__init__(self, parent=None, manager=parent, quickplot=quickplot)
         icon = QtGui.QIcon()
         icon.addPixmap(QtGui.QPixmap(":/res/ball.ico"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
         self.setWindowIcon(icon)
