@@ -8,10 +8,13 @@ from sas.qtgui.Plotting.SlicerModel import SlicerModel
 
 class AnnulusInteractor(BaseInteractor, SlicerModel):
     """
-    Select an annulus through a 2D plot.
-    This interactor is used to average 2D data  with the region
-    defined by 2 radius.
-    this class is defined by 2 Ringinterators.
+    AnnulusInteractor plots a data1D average of an annulus area defined in a
+    Data2D object. The data1D averaging itself is performed in sasdata by
+    manipulations.py
+
+    This class uses the RingInteractor class to define two rings of radius
+    r1 and r2 (Q1 and Q2). All Q points at a constant angle phi from the x-axis
+    are averaged together to provide a 1D array in phi from 0 to 180 degrees.
     """
     def __init__(self, base, axes, item=None, color='black', zorder=3):
 
@@ -48,6 +51,7 @@ class AnnulusInteractor(BaseInteractor, SlicerModel):
         self.outer_circle.qmax = self.qmax * 1.2
         self.update()
         self._post_data()
+        self.draw()
 
         self.setModelFromParams()
 
@@ -97,7 +101,7 @@ class AnnulusInteractor(BaseInteractor, SlicerModel):
         if data is None:
             return
 
-        from sas.sascalc.dataloader.manipulations import Ring
+        from sasdata.data_util.manipulations import Ring
         rmin = min(numpy.fabs(self.inner_circle.get_radius()),
                    numpy.fabs(self.outer_circle.get_radius()))
         rmax = max(numpy.fabs(self.inner_circle.get_radius()),
@@ -134,8 +138,8 @@ class AnnulusInteractor(BaseInteractor, SlicerModel):
             new_plot.ytransform = 'y'
             new_plot.yaxis("\\rm{Residuals} ", "/")
 
-        new_plot.group_id = "AnnulusPhi" + self.data.name
         new_plot.id = "AnnulusPhi" + self.data.name
+        new_plot.type_id = "Slicer" + self.data.name # Used to remove plots after changing slicer so they don't keep showing up after closed
         new_plot.is_data = True
         new_plot.xtransform = "x"
         new_plot.ytransform = "y"
@@ -148,7 +152,6 @@ class AnnulusInteractor(BaseInteractor, SlicerModel):
 
         if self.update_model:
             self.setModelFromParams()
-        self.draw()
 
     def validate(self, param_name, param_value):
         """
@@ -188,13 +191,14 @@ class AnnulusInteractor(BaseInteractor, SlicerModel):
         Redraw the plot with new parameters.
         """
         self._post_data(self.nbins)
+        self.draw()
 
-    def restore(self):
+    def restore(self, ev):
         """
         Restore the roughness for this layer.
         """
-        self.inner_circle.restore()
-        self.outer_circle.restore()
+        self.inner_circle.restore(ev)
+        self.outer_circle.restore(ev)
 
     def move(self, x, y, ev):
         """
@@ -232,6 +236,7 @@ class AnnulusInteractor(BaseInteractor, SlicerModel):
         self.outer_circle.set_cursor(outer, self.outer_circle._inner_mouse_y)
         # Post the data given the nbins entered by the user
         self._post_data(self.nbins)
+        self.draw()
 
     def draw(self):
         """
@@ -241,13 +246,13 @@ class AnnulusInteractor(BaseInteractor, SlicerModel):
 
 class RingInteractor(BaseInteractor):
     """
-     Draw a ring Given a radius
+     Draw a ring on a data2D plot centered at (0,0) given a radius
     """
     def __init__(self, base, axes, color='black', zorder=5, r=1.0, sign=1):
         """
         :param: the color of the line that defined the ring
         :param r: the radius of the ring
-        :param sign: the direction of motion the the marker
+        :param sign: the direction of motion the marker
 
         """
         BaseInteractor.__init__(self, base, axes, color=color)
@@ -340,7 +345,7 @@ class RingInteractor(BaseInteractor):
         """
         self.base.moveend(ev)
 
-    def restore(self):
+    def restore(self, ev):
         """
         Restore the roughness for this layer.
         """
@@ -353,7 +358,8 @@ class RingInteractor(BaseInteractor):
         """
         self._inner_mouse_x = x
         self._inner_mouse_y = y
-        self.base.base.update()
+        self.base.update()
+        self.base.draw()
 
     def set_cursor(self, x, y):
         """
